@@ -49,8 +49,9 @@ class LedgerClient:
             book_info["restrictions"]["minBalance"] = min_balance
         return self._execute("createBook", book_info)
 
-    def get_book(self, book_id: str):
-        return self._execute("getBook", book_id, read_only_method=True)
+    def get_book(self, book_id: str, timestamp: int = None):
+        filter = {"toTime": timestamp} if timestamp else None
+        return self._execute("getBook", book_id, filter, read_only_method=True)
 
     def put_book(self, book_id: str, restrictions: dict):
         return self._execute("putBook", book_id, restrictions)
@@ -95,9 +96,12 @@ class LedgerClient:
             raise Exception(result["rejectionReason"])
         return result
 
-    def post_void(self, operation_id_list: list, memo: str, metadata: dict):
+    def post_void(self, operation_id_list: list, memo: str, metadata: dict = None):
         void = dict()
         void["operationIds"] = operation_id_list
         void["memo"] = memo
         void["metadata"] = metadata or {}
-        return self._execute("postVoid", void)
+        result = self._execute("postVoid", void)
+        if result["status"] == OperationStatus.REJECTED.value:
+            raise Exception(result["rejectionReason"])
+        return result
